##########################################
## VfUCGenderGapNWLCStudyReplication1.r ##
##########################################
## Curtis Miller                        ##
## 9/15/14                              ##
##########################################

## This script is for replicating the results of the National Women's Law Center (NWLC) report "Underpaid and Overloaded."
## The data used is from IPUMS-CPS (2013), with low-wage occupations being defined as those occupations with median wages
## below $10.10 according to BLS OES data.

## This script creates a table of low-wage occupations. The CSV file then can be modified (by hand) to line up with IPUMS
## codes

# "national_M2013_dl.csv" (from BLS, a .xls file converted to .csv) and "cps_00002.csv" (an IPUMS data abstract) needs to be in the working directory for this script.

#bls_underwage_data <-read.csv('national_M2013_dl.csv')
# State version of the script: uncomment to activate
bls_underwage_data <-read.csv('state_m2013_dl.csv')

# Clean up data, restricting to "detailed" occupations for which the median wage is below $10.10/hr

attach(bls_underwage_data)
# Clean up data codes with interpretation
H_MEDIAN <- sapply(H_MEDIAN, as.character)
H_MEDIAN[which(H_MEDIAN == '*' | H_MEDIAN == '**')] <- NA
H_MEDIAN[which(H_MEDIAN == '#')] <- '90.00'
H_MEDIAN <- sapply(H_MEDIAN, as.numeric)
# Clean up OCC codes, making them numeric and stripping off the first three characters
OCC_CODE <- sapply(OCC_CODE, as.character)
OCC_CODE <- sub('-', '', OCC_CODE)
OCC_CODE <- sapply(OCC_CODE, as.numeric)
bls_underwage_data['OCC_CODE'] <- OCC_CODE

#selected_data <- which(OCC_GROUP == 'detailed' & H_MEDIAN <= 10.10)
# Utah state version
selected_data <- which(OCC_GROUP == 'detailed' & H_MEDIAN <= 10.10 & ST == 'UT')
occ_codes <- OCC_CODE[selected_data]

write.csv(bls_underwage_data[selected_data, ], 'Low_wage_occs.csv')