##############################################
## VfUCGenderGapParticipationRate_ACSData.r ##
##############################################
## Curtis Miller                            ##
## 10/8/14                                  ##
##############################################

## This script calculates the labor participation rate for women in Utah in 2014. It uses
## VfUCGenderGap_RawWageGapData1ACS.csv, so be sure that file is in the working directory.
## It is not a small file, so the packages ff and ffbase are used to extract data.
## StateFipsCodes.csv is also needed.

## This script calculates several aspects of participation rates. Aspects calculate
## include:
##    * Participation rate across time
##    * Participation rate across states
##    * (Others coming soon)

# Run these lines to install necessary packages
#install.packages('ff')
#install.packages('ffbase')
#install.packages('ggplot2')
#install.packages(devtools)
#library(devtools)
#install_github('pingr', 'rasmusab')

library(ff)
library(ffbase)
library(ggplot2)
#library(beepr)

# Read in the data from both files for manipulation
data1 <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData1ACS.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)
#beep()
#data2 <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData2ACS.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)
#beep()

selected.variables = c('YEAR', 'STATEFIP', 'SEX', 'LABFORCE', 'AGE', 'PERWT')
# Combine the data to be analyzed that is present in both files into one object
partic.data <- data1[selected.variables]
#partic.data <- ffdfappend(data1[selected.variables], data2[selected.variables])
#rm(data); gc()
# women.partic.rate.Utah.long will contain the participation rate of women in the labor force across years; same with men.partic.rate.long
#census.years <- c(1850, 1860, 1870, 1880, 1900, 1910, 1920, 1930, 1940, 1950, 1960, 1970, 1980, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012)
census.years <- 2000:2013
women.partic.rate.Utah.long = census.years
men.partic.rate.Utah.long = census.years
# Same for national longitudinal data
women.partic.rate.nat.long = census.years
men.partic.rate.nat.long = census.years

for (i in census.years) {
	# Make verbose
	cat('Calculating rates for i = ', i, '\n')
	year.data <- partic.data[ffwhich(partic.data, partic.data$YEAR == i),]
	year.data <- as.data.frame(year.data); gc()
	# Restrict to the subset of Utah data and individuals that are not NIU

	year.data <- year.data[which(year.data$SEX != 9 &
                                 year.data$LABFORCE != 0 &
                                 year.data$AGE >= 16),]

	# To calculate the participation rate, sum the weighted value of women (men) in the labor force, then divide by the weighted value of all women (men) in the population in question; because of division, the decimal place in PERWT does not need to be moved
	women.labor <- sum(year.data$PERWT[which(year.data$SEX == 2 & year.data$LABFORCE == 2)])
	women.total <- sum(year.data$PERWT[which(year.data$SEX == 2)])
	men.labor <- sum(year.data$PERWT[which(year.data$SEX == 1 & year.data$LABFORCE == 2)])
	men.total <- sum(year.data$PERWT[which(year.data$SEX == 1)])

	# Store participation rates in women.partic.rate.nat.long and men.partic.rate.long at appropriate location
	women.partic.rate.nat.long[which(women.partic.rate.nat.long == i)] <- women.labor / women.total
	men.partic.rate.nat.long[which(men.partic.rate.nat.long == i)] <- men.labor / men.total
  
  	# Repeat for Utah
  
	year.data <- year.data[which(year.data$STATEFIP == 49),]
  
	women.labor <- sum(year.data$PERWT[which(year.data$SEX == 2 & year.data$LABFORCE == 2)])
	women.total <- sum(year.data$PERWT[which(year.data$SEX == 2)])
	men.labor <- sum(year.data$PERWT[which(year.data$SEX == 1 & year.data$LABFORCE == 2)])
	men.total <- sum(year.data$PERWT[which(year.data$SEX == 1)])
	
	women.partic.rate.Utah.long[which(women.partic.rate.Utah.long == i)] <- women.labor / women.total
	men.partic.rate.Utah.long[which(men.partic.rate.Utah.long == i)] <- men.labor / men.total
	
}
#beep()

## I want to make a line graph for the participation rates, so we will create a data frame with year and the sexes participation rate,
## then plot using ggplot2.

partic.rate.long.data <- data.frame(Rate = c(women.partic.rate.Utah.long * 100, women.partic.rate.nat.long * 100, men.partic.rate.Utah.long * 100, men.partic.rate.nat.long * 100),
                                    Year = c(census.years, census.years, census.years, census.years),
                                    Sex = c(rep(c('Female'),times = length(women.partic.rate.Utah.long) + length(women.partic.rate.nat.long)), rep(c('Male'), times = length(men.partic.rate.Utah.long) + length(men.partic.rate.nat.long))),
				    Level = c(rep('Utah', times = length(women.partic.rate.Utah.long)), rep('National', times = length(women.partic.rate.nat.long)), rep('Utah', times = length(men.partic.rate.Utah.long)), rep('National', times = length(men.partic.rate.nat.long))))

write.csv(partic.rate.long.data, file = 'VfUCGenderGapParticipationRateLong_ACSData.csv')

# I want to be able to highlight recessions: the following data frame contains the beginning and end dates of recessions, along with parameters for the min and max coordinates of the box. The fractions represent month number minus one (so Jan is 0 and Dec is 11).
#recessions.draw.rect <- data.frame(begin = c(1969+11/12, 1973+10/12, 1980, 1981+6/12, 1990+6/12, 2001+2/12, 2007+11/12), end = c(1970+11/12, 1975+2/12, 1980+6/12, 1982+10/12, 1991+2/12, 2001+10/12, 2009+5/12), ymin = -Inf, ymax = Inf)
ggplot(partic.rate.long.data) +
	geom_line(aes(x = Year, y = Rate, color = Sex, linetype = Level), size = 1.1) +
	scale_linetype_manual(values = c('dashed', 'solid')) +
	#geom_rect(data = recessions.draw.rect, aes(xmin = begin, xmax = end, ymin = ymin, ymax = ymax), color = 'grey10', linetype = 0, alpha = 0.5, inherit.aes = F) +
	ggtitle("Men's and Women's Participation \n Rate in the Labor Force") +
  	ylab('Rate (as %)') +
	ylim(50, 100) +
	theme_bw() +
	scale_x_continuous(breaks = census.years) +
	theme(plot.title = element_text(size = rel(2)))

# Save plots in working directory
ggsave('SexLaborForceParticipationLongACS.png', width = 5.5, height = 4, units = 'in', scale = 1.5)
ggsave('SexLaborForceParticipationLongACS.wmf', width = 5.5, height = 4, units = 'in', scale = 1.5)

########################################################################################
########################################################################################
########################################################################################

## Let's now do a latitudinal examination of participation rate in the labor force. The file
## VfUCGenderGap_RawWageGapData1ACS_2013.csv is identical to
## VfUCGenderGap_RawWageGapData1ACS.csv, but includes the REPWTXX variables for
## computing standard errors directly from the data. This script utilizes this to
## calculate standard errors for the 2013 data (due to the size of the resulting files,
## this is not calculated for other years; there are major technical limitations).

# Load a new CSV file that contains the replicate weights variables
data2 <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData1ACS_2013.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)

# Create a vector containing the names of the 80 REPWTPXX vars
paste(rep('REPWTP', times = 80), 1:80, sep = '') -> replicate.vars

# First, load a CSV file containing state FIP codes
state.fip.code <- read.csv('StateFipCodes.csv')
# Only states are wanted, not regions or unidentified; this selects the desired subset (including DC)
state.fip.code <- state.fip.code[1:51,]

women.partic.rate.lat = 1:51
men.partic.rate.lat = 1:51

women.partic.rate.lat.se = 1:51
men.partic.rate.lat.se = 1:51

partic.data.2013 <- data2[c(selected.variables, replicate.vars)]
partic.data.2013 <- partic.data.2013[ffwhich(partic.data.2013, partic.data.2013$SEX != 9 &
                                               partic.data.2013$LABFORCE != 0 &
                                               partic.data.2013$AGE >= 16),]

## This function takes a vector x of the form 1:i (usually 1:51) for x, an ff object data, a sample weight for weight, and a call
## for output verbose. This function calculates and returns state labor force participation rates. data is usually restricted to 
## one gender.

calculate.partic.rate.lat <- function(x, verbose = FALSE, data, weight = 'PERWT') {
  for (i in 1:51) {
    if (verbose == TRUE) {
      cat('Calculating rate for i = ', i, '\n')
    }
    state.data <- as.data.frame(data[ffwhich(data, data$STATEFIP == state.fip.code$STATEFIP[i]),])
    
    # To calculate the participation rate, sum the weighted value in the labor force, then divide by the weighted value of all in the population in question; because of division, the decimal place in weight does not need to be moved
    labor <- sum(state.data[which(state.data$LABFORCE == 2),weight])
    total <- sum(state.data[[weight]])
    
    # Store participation rates in x at appropriate location
    x[i] <- labor / total
  }
  
  rm(state.data)
  return(x)
}

## This function takes a vector x of the form 1:i (usually 1:51) for x, an ff object data, the vector representing estimates
## called estimate, and a call for output verbose. This function calculates and returns state labor force participation rates
## standard errors using replicate weights. data is usually restricted to one gender.

calculate.partic.rate.se <- function(x, estimate, verbose = FALSE, data) {
  sum.square = rep(0, times = length(x))
  
  ## The formula for calculating the standard errors is
  ## SE(X) = sqrt(4/80 * sum(from r = 1 to 80, (X_r - X)^2))
  ## I calculate first the sum of squares.
  for (i in replicate.vars) {
    if (verbose == T) {
      cat('Calculating replicate for i = ', i, '\n')
    }
    sum.square <- sum.square + (calculate.partic.rate.lat(x, data = data, weight = i) - estimate) ^ 2
  }
  
  # Now to calculate the final SE
  x = sqrt(sum.square / 20)
  
  return(x)
}

women.partic.rate.lat <- calculate.partic.rate.lat(women.partic.rate.lat, verbose = T, data = partic.data.2013[ffwhich(partic.data.2013, partic.data.2013$SEX == 2),])
men.partic.rate.lat <- calculate.partic.rate.lat(men.partic.rate.lat, verbose = T, data = partic.data.2013[ffwhich(partic.data.2013, partic.data.2013$SEX == 1),])

women.partic.rate.lat.se <- calculate.partic.rate.se(women.partic.rate.lat.se, verbose = T, estimate = women.partic.rate.lat, data = partic.data.2013[ffwhich(partic.data.2013, partic.data.2013$SEX == 2),])
men.partic.rate.lat.se <- calculate.partic.rate.se(men.partic.rate.lat.se, verbose = T, estimate = men.partic.rate.lat, data = partic.data.2013[ffwhich(partic.data.2013, partic.data.2013$SEX == 1),])

# Store participation rates in women.partic.rate.long and men.partic.rate.long at appropriate location
nat.sex.partic.rate <- data.frame(Rate = c(women.partic.rate.nat.long[length(women.partic.rate.nat.long)], men.partic.rate.nat.long[length(men.partic.rate.nat.long)]),
                                           Sex = c('Female', 'Male'))

# Create a data frame containing the data that can be used by ggplot2
partic.rate.lat.data <- data.frame(Rate = c(women.partic.rate.lat * 100, men.partic.rate.lat * 100),
                                   SE = c(women.partic.rate.lat.se * 100, men.partic.rate.lat.se * 100),
                                   State = c(as.character(state.fip.code$State[1:51]), as.character(state.fip.code$State[1:51])),
                                   Sex = c(rep(c('Female'), times = length(women.partic.rate.lat)), rep(c('Male'), times = length(women.partic.rate.lat))))

write.csv(partic.rate.lat.data, file = 'VfUCGenderGapParticipationRateLat_ACSData.csv')

ggplot(partic.rate.lat.data) +
	geom_point(aes(x = Rate, y = reorder(State, Rate), color = Sex), size = 4) +
	geom_hline(yintercept = 38, color = 'orange', size = 3, alpha = .2) +
	geom_vline(xintercept = c(women.partic.rate.nat.long[length(women.partic.rate.nat.long)] * 100, men.partic.rate.nat.long[length(men.partic.rate.nat.long)] * 100), color = c('#F8766D', '#00BFC4')) +
	geom_text(x = women.partic.rate.Utah.long[length(women.partic.rate.Utah.long)] * 100 + .5,
            y = 38,
            label= round(women.partic.rate.Utah.long[length(women.partic.rate.Utah.long)] * 100, digits = 1),
            hjust=0,
            vjust=0,
            size =3.5,
            color = '#F8766D') +
  	geom_text(x = men.partic.rate.Utah.long[length(men.partic.rate.Utah.long)] * 100 + .5,
            y = 38,
            label= round(men.partic.rate.Utah.long[length(men.partic.rate.Utah.long)] * 100, digits = 1),
            hjust=0,
            vjust=0,
            size =3,
            color = '#00BFC4') +
  	theme_bw() +
	geom_errorbarh(aes(x = Rate, y = reorder(State, Rate), xmin = Rate - SE, xmax = Rate + SE, color = Sex), linetype = 'twodash') +
	ggtitle("Men's and Women's Participation \n Rate in the Labor Force, 2013") +
  	xlab('Rate (as %)') +
	ylab('State') +
	scale_x_continuous(breaks = c(seq(50, 80, by = 10), round(women.partic.rate.nat.long[length(women.partic.rate.nat.long)] * 100, digits = 1), round(men.partic.rate.nat.long[length(men.partic.rate.nat.long)] * 100, digits = 1))) +
	theme(panel.grid.major.x = element_blank(),
	      panel.grid.minor.x = element_blank(),
	      panel.grid.major.y = element_line(color = 'grey60', linetype = 'dotted'),
	      axis.text.x = element_text(angle = 35, hjust = 1, vjust = 1),
	      plot.title = element_text(size = rel(2)))

# Save plots in working directory
ggsave('SexLaborForceParticipationLatACS.png', width = 8.75, height = 7.5, units = 'in', scale = 1.5)
ggsave('SexLaborForceParticipationLatACS.wmf', width = 8.75, height = 7.5, units = 'in', scale = 1.5)
