##############################################
## VfUCGenderGapPotential.r                 ##
##############################################
## Curtis Miller                            ##
## 12/7/14                                  ##
##############################################

## This script calculates the potential earings of women in Utah if the gap were gone. It uses
## VfUCGenderGap_RawWageGapData1ACS_2013.csv, so be sure that file is in the working directory.
## It is not a small file, so the packages ff and ffbase are used to extract data.

library(ff)
library(ffbase)

# Load a new CSV file that contains the replicate weights variables
data1 <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData1ACS_2013.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)

hours.data <- as.data.frame(data1[ffwhich(data1, data1$EMPSTAT == 1 & data1$WKSWORK2 == 6 & data1$UHRSWORK >= 35), c('PERWT', 'INCEARN', 'STATEFIP', 'SEX')])

Utah.men <- which(hours.data$SEX == 1 & hours.data$STATEFIP == 49)
Utah.women <- which(hours.data$SEX == 2 & hours.data$STATEFIP == 49)
nat.women <- which(hours.data$SEX == 2)
nat.men <- which(hours.data$SEX == 1)

Utah.agg.earn.women <- sum(as.numeric(hours.data$INCEARN[Utah.women] * hours.data$PERWT[Utah.women]))
Utah.agg.earn.men <- sum(as.numeric(hours.data$INCEARN[Utah.men] * hours.data$PERWT[Utah.men]))

Utah.men.avg.earnings <- weighted.mean(hours.data$INCEARN[Utah.men], w = hours.data$PERWT[Utah.men])
Utah.women.avg.earnings <- weighted.mean(hours.data$INCEARN[Utah.women], w = hours.data$PERWT[Utah.women])
nat.women.avg.earnings <- weighted.mean(hours.data$INCEARN[nat.women], w = hours.data$PERWT[nat.women])

agg.inc.gap.close <- (1/.7) * Utah.agg.earn.women - Utah.agg.earn.women
agg.inc.Utah.close <- (.79/.7) * Utah.agg.earn.women - Utah.agg.earn.women
