############################################
## VfUCGenderGapSimpleParticipationRate.r ##
############################################
## Curtis Miller                          ##
## 9/18/14                                ##
############################################

## This script calculates the labor participation rate for women in Utah in 2014. It uses
## VfUCGenderGap_RawWageGapData1.csv, so be sure that file is in the working directory. It
## is not a small file, so the packages ff and ffbase are used to extract data.

# Run these lines to install necessary packages
#install.packages('ff')
#install.packages('ffbase')

library(ff)
library(ffbase)

# Read in the data, select the desired subset, then create a dataframe with that subset
data <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData1.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)
selected.variables = c('YEAR', 'STATEFIP', 'SEX', 'EMPSTAT')
partic.data <- data[selected.variables]
partic.data <- partic.data[ffwhich(partic.data, partic.data$YEAR == 2014),]
partic.data <- as.data.frame(partic.data); gc()
partic.data <- partic.data[which((partic.data$STATEFIP == 49) & (partic.data$SEX != 9) & (partic.data$EMPSTAT != 00)),]

# Calculate the population proportions
women.labor <- length(which(partic.data$SEX == 2 & partic.data$EMPSTAT %in% c(1,10,12,20,21,22)))
women.total <- length(which(partic.data$SEX == 2))
men.labor <- length(which(partic.data$SEX == 1 & partic.data$EMPSTAT %in% c(1,10,12,20,21,22)))
men.total <- length(which(partic.data$SEX == 1))

part.rates = c(men.labor / men.total, women.labor / women.total)
names(part.rates) <- c('Men', 'Women')

# Create a simple bar chart
barplot(part.rates, main = 'Percentage of sexes in labor force', col = rainbow(2))
