##############################################
## VfUCGenderMaritalMomRate.r               ##
##############################################
## Curtis Miller                            ##
## 11/12/14                                 ##
##############################################

## This script calculates the percentage of women within parental/marital status. It uses
## VfUCGenderGap_RawWageGapData1ACS_2013.csv, so be sure that file is in the working directory.
## It is not a small file, so the packages ff and ffbase are used to extract data.
## StateFipsCodes.csv is also needed.

## This script calculates several aspects of participation rates. Aspects calculate
## include:
##    * Percentage of women in marital and parental status

# Run these lines to install necessary packages
#install.packages('ff')
#install.packages('ffbase')
#install.packages('ggplot2')
#install.packages('devtools')
#library(devtools)
#install_github('pingr', 'rasmusab')
#install.packages('matrixStats')

library(ff)
library(ffbase)
library(ggplot2)

data1 <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData1ACS_2013.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)

selected.variables = c('STATEFIP', 'SEX', 'PERWT', 'AGE', 'MARST', 'NCHILD')
paste(rep('REPWTP', times = 80), 1:80, sep = '') -> replicate.vars

mom.rate.data <- data1[c(selected.variables, replicate.vars)]
mom.rate.data <- mom.rate.data[ffwhich(mom.rate.data, mom.rate.data$SEX == 2 & mom.rate.data$AGE >= 18),]
mom.rate.Utah <- 1:5
mom.rate.nat <- mom.rate.Utah

mom.rate.Utah.se <- mom.rate.Utah
mom.rate.nat.se <- mom.rate.nat

calculate.mom.rate <- function(x, verbose = FALSE, data, weight = 'PERWT') {
  i = 1
  total <- sum(as.vector(data[[weight]]))

  if (verbose == T) {
    cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 1
  mom.data <- data[ffwhich(data, data$MARST >= 1 & data$MARST <= 3),]
  mom.data <- as.vector(mom.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(mom.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
    cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 2
  mom.data <- data[ffwhich(data, data$MARST >= 4 & data$MARST <= 5),]
  mom.data <- as.vector(mom.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(mom.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
    cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 3
  mom.data <- data[ffwhich(data, data$MARST == 6),]
  mom.data <- as.vector(mom.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(mom.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
    cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 4
  mom.data <- data[ffwhich(data, data$NCHILD > 0),]
  mom.data <- as.vector(mom.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(mom.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
    cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 5
  mom.data <- data[ffwhich(data, data$NCHILD == 0),]
  mom.data <- as.vector(mom.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(mom.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  return(x)
}

calculate.rate.se <- function(x, estimate, verbose = FALSE, data, statefip = NA) {
  sum.square = rep(0, times = length(x))
  
  ## The formula for calculating the standard errors is
  ## SE(X) = sqrt(4/80 * sum(from r = 1 to 80, (X_r - X)^2))
  ## I calculate first the sum of squares.
  for (i in replicate.vars) {
    if (verbose == T) {
      cat('Calculating replicate for i = ', i, '\n')
    }
    sum.square <- sum.square + (calculate.mom.rate(x, data = data, weight = i) - estimate) ^ 2
  }
  
  # Now to calculate the final SE
  x = sqrt(sum.square / 20)
  
  return(x)
}

mom.rate.nat <- calculate.mom.rate(mom.rate.nat, verbose = T, data = mom.rate.data)
mom.rate.Utah <- calculate.mom.rate(mom.rate.Utah, verbose = T, data = mom.rate.data[ffwhich(mom.rate.data, mom.rate.data$STATEFIP == 49),])

mom.rate.nat.se <- calculate.rate.se(mom.rate.nat.se, verbose = T, data = mom.rate.data, estimate = mom.rate.nat)
mom.rate.Utah.se <- calculate.rate.se(mom.rate.Utah.se, verbose = T, data = mom.rate.data[ffwhich(mom.rate.data, mom.rate.data$STATEFIP == 49),], estimate = mom.rate.Utah)

# Create a dataframe containing the data, and save it to a csv file
mom.rate.data.frame <- data.frame(Rate = c(mom.rate.Utah, mom.rate.nat) * 100,
                                 SE = c(mom.rate.Utah.se, mom.rate.nat.se) * 100,
                                 Group = rep(c('Married', 'Unmarried', 'Never Married', 'Children Present', 'Children Not Present'), times = 2),
                                 Level = c(rep('Utah', times = length(mom.rate.Utah)), rep('National', times = length(mom.rate.nat))))

write.csv(mom.rate.data.frame, file = 'VfUCMomRate.csv')

ggplot(mom.rate.data.frame) +
  geom_point(aes(x = Rate, y = Group, color = Level), size = 4) +
  geom_errorbarh(aes(x = Rate, y = Group, xmin = Rate - SE, xmax = Rate + SE, color = Level), linetype = 'twodash') +
  geom_hline(yintercept = 2.5) +
  ggtitle("Percent of Women 18 and Older Within \n Different Marital and Parental Groups, 2013") +
  xlab('Rate (as %)') +
  ylab('Marital/Parental Group') +
  theme_bw() +
  theme(panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid.major.y = element_line(color = 'grey60', linetype = 'dotted'),
        axis.text.x = element_text(angle = 35, hjust = 1, vjust = 1),
        plot.title = element_text(size = rel(2)))

# Save plots in working directory
ggsave('MaritalParentalRate.png', width = 6, height = 2, units = 'in', scale = 1.5)
ggsave('MaritalParentalRate.wmf', width = 6, height = 2, units = 'in', scale = 1.5)
