##############################################
## VfUCRateEducMenWomen.r                   ##
##############################################
## Curtis Miller                            ##
## 11/17/14                                 ##
##############################################

## This script calculates the percentage of the sexes at different levels of education. This
## file uses the csv files created by VfUCRateEduc.r and VfUCRateEducMen.r, so be sure to
## have ran those scripts first and have the files VfUCRateEduc.csv and
## VfUCRateEducMen.csv in the working directory.

## This script calculates several aspects of participation rates. Aspects calculate
## include:
##    * Percentage of men and women at level of education

#install.packages('ggplot2')

library(ggplot2)

# Load the data files
educ.rate.data.frame.women <- read.csv('VfUCRateEduc.csv')
educ.rate.data.frame.men <- read.csv('VfUCRateEducMen.csv')

educ.rate.data.frame <- data.frame(Men = educ.rate.data.frame.men$Utah.Rate, Women = educ.rate.data.frame.women$Utah.Rate, Men.SE = educ.rate.data.frame.men$Utah.SE, Women.SE = educ.rate.data.frame.women$Utah.SE, Educ = educ.rate.data.frame.men$Educ)

cbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "#999999", '#D50F64')

ggplot(educ.rate.data.frame) +
  geom_segment(aes(x = 0, xend = 15, y = Women, yend = Men, color = Educ), size = .75) +
  geom_point(aes(x = 0, y = Women, color = Educ), size = 3) +
  geom_point(aes(x = 15, y = Men, color = Educ), size = 3) +
  scale_colour_manual(values=cbPalette) +
  ggtitle("Level of Education in 2013 \n Among Utahns 25-64") +
  xlab('') +
  ylab('') +
  xlim(-5, 20) +
  ylim(0, 1.2*25) +
  geom_text(label = 'Utah', x = 0, y = 1.1*25, size = 5) +
  geom_text(label = 'Nation', x = 15, y = 1.1*25, size = 5) +
  geom_text(aes(label = paste(round(Men, digits = 1), '%', sep = ''), x = 15, y = Men), hjust = -0.5, size = 2.6) +
  geom_text(aes(label = paste(round(Women, digits = 1), '%', sep = ''), x = 0, y = Women), hjust = 1.5, size = 2.6) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.ticks = element_blank(),
        axis.text = element_blank(),
        panel.border = element_blank(),
        axis.title.y = element_text(vjust = 3),
        plot.title = element_text(size = rel(1.5)))

ggsave('EducRateSexes.png', width = 5, height = 5, units = 'in', scale = 1.5)
ggsave('EducRateSexes.wmf', width = 5, height = 5, units = 'in', scale = 1.5)

educ.rate.data.frame <- data.frame(Rate = c(educ.rate.data.frame.women$Utah.Rate, educ.rate.data.frame.women$Nat.Rate, educ.rate.data.frame.men$Utah.Rate, educ.rate.data.frame.men$Nat.Rate),
				   Educ = rep(educ.rate.data.frame.women$Educ, times = 4),
				   Group = rep(c('Utah Women', 'Women Nationally', 'Utah Men', 'Men Nationally'), each = length(educ.rate.data.frame.women$Utah.Rate)))

educ.rate.data.frame$pos = c(cumsum(educ.rate.data.frame.women$Utah.Rate), cumsum(educ.rate.data.frame.women$Nat.Rate), cumsum(educ.rate.data.frame.men$Utah.Rate), cumsum(educ.rate.data.frame.men$Nat.Rate)) - 0.5 * educ.rate.data.frame$Rate
educ.rate.data.frame$Color = rep(c(rep('black', times = 4), 'white', rep('black', times = 5)), times = 4)

ggplot(educ.rate.data.frame) +
	geom_bar(aes(Rate, x = Group, fill = Educ), stat = 'identity') +
	scale_fill_manual(values=cbPalette, breaks = educ.rate.data.frame.women$Educ, guide = guide_legend(reverse=TRUE)) +
	ggtitle("Level of Education Among \n Individuals 25-64, 2013") +
	ylab('Rate (as %)') +
	geom_text(aes(y = pos, x = Group, label = paste(round(Rate, digits = 2), '%', sep = '')), size = 2.5, color = as.character(educ.rate.data.frame$Color), angle = -30) +
	coord_flip() +
	theme_bw() +
	theme(plot.title = element_text(size = rel(2)),
	      axis.text.x = element_text(angle = 35, hjust = 1, vjust = 1))

ggsave('EducRateSexesBar.png', width = 10, height = 7, units = 'in', scale = 1.5)
ggsave('EducRateSexesBar.wmf', width = 10, height = 7, units = 'in', scale = 1.5)
