##############################################
## VfUCWorkRate.r                           ##
##############################################
## Curtis Miller                            ##
## 11/25/14                                 ##
##############################################

## This script calculates the percentage of men and women in full or part or no work. It uses
## VfUCGenderGap_RawWageGapData1ACS_2013.csv, so be sure that file is in the working directory.
## It is not a small file, so the packages ff and ffbase are used to extract data.
## StateFipsCodes.csv is also needed.

## This script calculates several aspects of participation rates. Aspects calculate
## include:
##    * Percentage of men and women working full-time, part-time, unemployed, or not in labor force

# Run these lines to install necessary packages
#install.packages('ff')
#install.packages('ffbase')
#install.packages('ggplot2')
#install.packages('devtools')
#library(devtools)
#install_github('pingr', 'rasmusab')
#install.packages('matrixStats')

library(ff)
library(ffbase)
library(ggplot2)

data1 <- read.csv.ffdf(file = 'VfUCGenderGap_RawWageGapData1ACS_2013.csv', first.rows = 10000, next.rows = 50000, VERBOSE = T, colClasses = NA)

selected.variables = c('STATEFIP', 'SEX', 'PERWT', 'EMPSTAT', 'UHRSWORK', 'WKSWORK2', 'AGE')

paste(rep('REPWTP', times = 80), 1:80, sep = '') -> replicate.vars

work.rate.data <- data1[c(selected.variables, replicate.vars)]
work.rate.data <- work.rate.data[ffwhich(work.rate.data, work.rate.data$SEX != 9 & work.rate.data$EMPSTAT != 0 & work.rate.data$AGE >= 16),]

# These vectors will contain the desired rates. 1 corresponds to full-time year-round workers, 2 is part-time workers, 3 is unemployed, 4 is not in labor force
work.rate.women.Utah <- 1:5
work.rate.women.nat <- work.rate.women.Utah

work.rate.men.Utah <- 1:5
work.rate.men.nat <- work.rate.men.Utah

work.rate.women.Utah.se <- work.rate.women.Utah
work.rate.women.nat.se <- work.rate.women.nat

work.rate.men.Utah.se <- work.rate.men.Utah
work.rate.men.nat.se <- work.rate.men.nat

calculate.work.rate <- function(x, verbose = FALSE, data, weight = 'PERWT') {
  i = 1
  total <- sum(as.vector(data[[weight]]))

  if (verbose == T) {
    cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 1
  work.data <- data[ffwhich(data, data$EMPSTAT == 1 &
  			  	data$UHRSWORK >= 35 &
  			  	data$WKSWORK2 == 6),]
  work.data <- as.vector(work.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(work.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
  	cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 2
  work.data <- data[ffwhich(data, data$EMPSTAT == 1 &
  			  	data$UHRSWORK < 35 &
  			  	data$WKSWORK2 >= 1),]
  work.data <- as.vector(work.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(work.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
  	cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 3
  work.data <- data[ffwhich(data, data$EMPSTAT == 2),]
  work.data <- as.vector(work.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(work.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
  	cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 4
  work.data <- data[ffwhich(data, data$EMPSTAT == 3),]
  work.data <- as.vector(work.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(work.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  if (verbose == T) {
  	cat('Calculating rate for i = ', i, '\n')
  }
  # Select the subset of the data corresponding to 1
  work.data <- data[ffwhich(data, data$EMPSTAT == 1 &
  			  	data$UHRSWORK >= 35 &
  			  	data$WKSWORK2 < 6),]
  work.data <- as.vector(work.data[[weight]])
  
  # Calculate the weighted rate
  selected <- sum(work.data)
  
  # Calculate the wage gap and assign to the appropriate location in x
  x[i] <- selected / total
  i <- i + 1
  
  return(x)
}

calculate.rate.se <- function(x, estimate, verbose = FALSE, data, statefip = NA) {
  sum.square = rep(0, times = length(x))
  
  ## The formula for calculating the standard errors is
  ## SE(X) = sqrt(4/80 * sum(from r = 1 to 80, (X_r - X)^2))
  ## I calculate first the sum of squares.
  for (i in replicate.vars) {
    if (verbose == T) {
      cat('Calculating replicate for i = ', i, '\n')
    }
    sum.square <- sum.square + (calculate.work.rate(x, data = data, weight = i) - estimate) ^ 2
  }
  
  # Now to calculate the final SE
  x = sqrt(sum.square / 20)
  
  return(x)
}

work.rate.women.nat <- calculate.work.rate(work.rate.women.nat, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$SEX == 2),])
work.rate.women.Utah <- calculate.work.rate(work.rate.women.Utah, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$STATEFIP == 49 & work.rate.data$SEX == 2),])
work.rate.men.nat <- calculate.work.rate(work.rate.men.nat, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$SEX == 1),])
work.rate.men.Utah <- calculate.work.rate(work.rate.men.Utah, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$STATEFIP == 49 & work.rate.data$SEX == 1),])

work.rate.women.nat.se <- calculate.rate.se(work.rate.women.nat.se, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$SEX == 2),], estimate = work.rate.women.nat)
work.rate.women.Utah.se <- calculate.rate.se(work.rate.women.Utah.se, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$STATEFIP == 49 & work.rate.data$SEX == 2),], estimate = work.rate.women.Utah)
work.rate.men.nat.se <- calculate.rate.se(work.rate.men.nat.se, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$SEX == 1),], estimate = work.rate.men.nat)
work.rate.men.Utah.se <- calculate.rate.se(work.rate.men.Utah.se, verbose = T, data = work.rate.data[ffwhich(work.rate.data, work.rate.data$STATEFIP == 49 & work.rate.data$SEX == 1),], estimate = work.rate.men.Utah)

# Create a dataframe containing the data, and save it to a csv file
work.rate.data.frame <- data.frame(Rate = c(work.rate.women.nat, work.rate.women.Utah, work.rate.men.nat, work.rate.men.Utah) * 100,
				   Level = rep(c('National', 'Utah'), each = length(work.rate.women.Utah), times = 2),
                                 SE = c(work.rate.women.Utah.se, work.rate.men.Utah.se, work.rate.women.nat.se, work.rate.men.nat.se) * 100,
                                 Group = rep(c('Full-Time Year-Round', 'Part-Time', 'Unemployed', 'Not In Labor Force', 'Full-Time Not Year-Round'), times = 4),
                                 Sex = c(rep('Female', times = length(c(work.rate.women.Utah, work.rate.women.nat))), rep('Male', times = length(c(work.rate.men.Utah, work.rate.men.nat)))))

write.csv(work.rate.data.frame, file = 'VfUCWorkRate.csv')

ggplot(work.rate.data.frame) +
  geom_point(aes(x = Rate, y = Group, color = Sex, pch = Level), size = 4) +
  scale_y_discrete(limits = c('Full-Time Year-Round', 'Full-Time Not Year-Round', 'Part-Time', 'Unemployed', 'Not In Labor Force')) +
#  geom_errorbarh(aes(x = Rate, y = Group, xmin = Rate - SE, xmax = Rate + SE, color = Sex), linetype = 'twodash') +
  ggtitle("Percent of People In Different Employment Groups, 2013") +
  xlab('Rate (as %)') +
  ylab('Employment Status') +
  theme_bw() +
  theme(panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid.major.y = element_line(color = 'grey60', linetype = 'dotted'),
        axis.text.x = element_text(angle = 35, hjust = 1, vjust = 1),
        plot.title = element_text(size = rel(2)))

# Save plots in working directory
ggsave('WorkRate.png', width = 8, height = 2, units = 'in', scale = 1.5)
ggsave('WorkRate.wmf', width = 8, height = 2, units = 'in', scale = 1.5)
